==> tiger-test-lib-3.0.1-sources.jar: de/gematik/test/tiger/lib/serenityrest/SerenityRestUtils.java <==
/*
 * Copyright (c) 2024 gematik GmbH
 * 
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an 'AS IS' BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.gematik.test.tiger.lib.serenityrest;

import de.gematik.test.tiger.proxy.TigerProxy;
import io.restassured.RestAssured;
import lombok.AccessLevel;
import lombok.NoArgsConstructor;
import lombok.extern.slf4j.Slf4j;

@Slf4j
@NoArgsConstructor(access = AccessLevel.PRIVATE)
public class SerenityRestUtils {

  public static void setupSerenityRest(TigerProxy localTigerProxyProxy) {
    RestAssured.proxy("localhost", localTigerProxyProxy.getProxyPort());

    RestAssured.trustStore(localTigerProxyProxy.buildTruststore());

    RestAssured.filters(
        (requestSpec, responseSpec, ctx) -> {
          try {
            log.trace(
                "Sending Request "
                    + requestSpec.getMethod()
                    + " "
                    + requestSpec.getURI()
                    + " via proxy "
                    + requestSpec.getProxySpecification());
            return ctx.next(requestSpec, responseSpec);
          } catch (Exception e) {
            throw new TigerSerenityRestException(
                "Error while retrieving "
                    + requestSpec.getMethod()
                    + " "
                    + requestSpec.getURI()
                    + " via proxy "
                    + requestSpec.getProxySpecification(),
                e);
          }
        });
  }

  private static class TigerSerenityRestException extends RuntimeException {

    public TigerSerenityRestException(String s, Exception e) {
      super(s, e);
    }
  }
}

==> tiger-test-lib-3.7.0-sources.jar: de/gematik/test/tiger/lib/serenityrest/SerenityRestUtils.java <==
/*
 * Copyright 2024 gematik GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.gematik.test.tiger.lib.serenityrest;

import de.gematik.test.tiger.proxy.TigerProxy;
import io.restassured.RestAssured;
import lombok.AccessLevel;
import lombok.NoArgsConstructor;
import lombok.extern.slf4j.Slf4j;

@Slf4j
@NoArgsConstructor(access = AccessLevel.PRIVATE)
public class SerenityRestUtils {

  public static void setupSerenityRest(TigerProxy localTigerProxyProxy) {
    RestAssured.proxy("localhost", localTigerProxyProxy.getProxyPort());

    RestAssured.trustStore(localTigerProxyProxy.buildTruststore());

    RestAssured.filters(
        (requestSpec, responseSpec, ctx) -> {
          try {
            log.trace(
                "Sending Request {} {} via proxy {}",
                requestSpec.getMethod(),
                requestSpec.getURI(),
                requestSpec.getProxySpecification());
            return ctx.next(requestSpec, responseSpec);
          } catch (Exception e) {
            log.error(
                "Failed sending request {} {} via proxy {}",
                requestSpec.getMethod(),
                requestSpec.getURI(),
                requestSpec.getProxySpecification(),
                e);
            throw e;
          }
        });
  }
}
